@@ -244,7 +244,7 @@ calculate_market_average <- function(data) {
       # Alias emission_factor_corporate_economy
       .x = list(.data$production * .data$emission_factor)
     ) %>%
-    tidyr::unnest(cols = .data$.x) %>%
+    unnest(cols = .data$.x) %>%
     group_by(.data$sector, .data$year) %>%
     summarize(.x = sum(.data$.x / .data$sector_total_production)) %>%
     rename(emission_factor_corporate_economy = .data$.x) %>%
